@@ -5,9 +5,11 @@
 #' using the INSPIRE ATOM service.
 #'
 #' @references
-#' [API Documentation](https://www.catastro.minhap.es/webinspire/documentos/inspire-ATOM.pdf)
+#' [API
+#' Documentation](https://www.catastro.minhap.es/webinspire/documentos/inspire-ATOM.pdf)
 #'
-#' [INSPIRE Services for Cadastral Cartography](https://www.catastro.minhap.es/webinspire/index.html)
+#' [INSPIRE Services for Cadastral
+#' Cartography](https://www.catastro.minhap.es/webinspire/index.html)
 #'
 #' @family INSPIRE
 #' @family ATOM
@@ -15,7 +17,7 @@
 #' @family spatial
 #'
 #' @export
-#' @return A `sf` object.
+#' @return A \CRANpkg{sf} object.
 #'
 #' @inheritParams catr_atom_get_parcels
 #' @param what Information to load. It could be `"building"` for buildings,
@@ -74,10 +76,7 @@ catr_atom_get_buildings <- function(munic,
       all <- all[linesto, ]
     } else {
       if (verbose) {
-        message(
-          "Ignoring 'to' parameter. No results for ",
-          to
-        )
+        message("Ignoring 'to' parameter. No results for ", to)
       }
     }
   }
@@ -87,7 +86,8 @@ catr_atom_get_buildings <- function(munic,
   if (is.na(findmunic)) {
     message(
       "No Municipality found for ", munic, " ", to,
-      ". Check available municipalities with catr_atom_get_buildings_db_all()"
+      ". Check available municipalities with ",
+      "catr_atom_get_buildings_db_all()"
     )
     return(invisible(NA))
   }
@@ -100,7 +100,8 @@ catr_atom_get_buildings <- function(munic,
     )
   }
 
-  municurls <- catr_atom_get_buildings_db_to(as.character(m$territorial_office),
+  municurls <- catr_atom_get_buildings_db_to(
+    as.character(m$territorial_office),
     cache = cache,
     update_cache = update_cache,
     cache_dir = cache_dir,
@@ -110,9 +111,9 @@ catr_atom_get_buildings <- function(munic,
   ref <- unlist(strsplit(m$munic, "-"))[1]
 
   # Download from url
-  api_entry <- municurls[grepl(ref, municurls$munic,
-    ignore.case = TRUE
-  ), ]$url
+  api_entry <- municurls[
+    grepl(ref, municurls$munic, ignore.case = TRUE),
+  ]$url
 
   filename <- basename(api_entry)
 
@@ -125,10 +126,7 @@ catr_atom_get_buildings <- function(munic,
   # To a new directory
   # Get cached dir
   cache_dir <- catr_hlp_cachedir(cache_dir)
-  exdir <- file.path(
-    cache_dir,
-    gsub(".zip$", "", filename)
-  )
+  exdir <- file.path(cache_dir, gsub(".zip$", "", filename))
 
   if (!dir.exists(exdir)) dir.create(exdir, recursive = TRUE)
   unzip(path, exdir = exdir, junkpaths = TRUE, overwrite = TRUE)
